@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::AnyViewer;
-$Config::Model::Tk::AnyViewer::VERSION = '1.357';
+$Config::Model::Tk::AnyViewer::VERSION = '1.358';
 use strict;
 use warnings;
 use Carp;
@@ -109,7 +109,7 @@ sub add_help {
     if ( $force_text_widget or $help =~ /\n/ or length($help) > 50 ) {
         $widget = $help_frame->PodText( -height => 6, -scrollbars => 'oe' );
         $widget->base_font_size(12);
-        $widget->pack(@fxe1);
+        $widget->pack(@fbe1);
         $cw->update_help( $widget, $help );
     }
 
