@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::HashEditor;
-$Config::Model::Tk::HashEditor::VERSION = '1.357';
+$Config::Model::Tk::HashEditor::VERSION = '1.358';
 use strict;
 use warnings;
 use Carp;
@@ -229,7 +229,7 @@ sub Populate {
     $cw->add_warning( $hash, 'edit' )->pack(@fx);
     $cw->add_info_button()->pack( @fx, qw/-anchor n/ );
     $cw->add_summary($hash)->pack(@fx);
-    $cw->add_description($hash)->pack(@fx);
+    $cw->add_description($hash)->pack(@fbe1);
 
     $cw->Tk::Frame::Populate($args);
 }
