@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::HashViewer;
-$Config::Model::Tk::HashViewer::VERSION = '1.357';
+$Config::Model::Tk::HashViewer::VERSION = '1.358';
 use strict;
 use warnings;
 use Carp;
@@ -59,7 +59,7 @@ sub Populate {
     $cw->add_annotation($hash)->pack(@fx);
     $cw->add_warning( $hash, 'view' )->pack(@fx);
     $cw->add_summary($hash)->pack(@fx);
-    $cw->add_description($hash)->pack(@fx);
+    $cw->add_description($hash)->pack(@fbe1);
 
     $cw->add_info_button()->pack( -side => 'left', @fxe1 );
     $cw->add_editor_button($path)->pack( -side => 'right', @fxe1 );
