@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor;
-$Config::Model::Tk::LeafEditor::VERSION = '1.357';
+$Config::Model::Tk::LeafEditor::VERSION = '1.358';
 use strict;
 use warnings;
 use Carp;
@@ -121,7 +121,7 @@ sub Populate {
     $cw->add_warning( $leaf, 'edit' )->pack(@fx);
     $cw->add_info_button()->pack( @fx, qw/-anchor n/ );
     $cw->add_summary($leaf)->pack(@fx);
-    $cw->add_description($leaf)->pack(@fx);
+    $cw->add_description($leaf)->pack(@fbe1);
     my ( $help_frame, $help_widget ) = $cw->add_help( 'help on value' => '', 1 );
     $help_frame->pack(@fx);
 
