@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafViewer;
-$Config::Model::Tk::LeafViewer::VERSION = '1.357';
+$Config::Model::Tk::LeafViewer::VERSION = '1.358';
 use strict;
 use warnings;
 use 5.10.1;
@@ -91,7 +91,7 @@ sub Populate {
 
     $cw->add_annotation($leaf)->pack(@fx);
     $cw->add_summary($leaf)->pack(@fx);
-    $cw->add_description($leaf)->pack(@fx);
+    $cw->add_description($leaf)->pack(@fbe1);
     $cw->add_warning( $leaf, 'view' )->pack(@fx);
     $cw->add_help( 'value help' => $leaf->get_help( $cw->{value} ) )->pack(@fx);
     $cw->add_info_button()->pack( @fxe1, -side => 'left', -anchor => 'n' );
