@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListEditor;
-$Config::Model::Tk::ListEditor::VERSION = '1.357';
+$Config::Model::Tk::ListEditor::VERSION = '1.358';
 use strict;
 use warnings;
 use Carp;
@@ -88,7 +88,7 @@ sub Populate {
 
     $cw->ConfigModelNoteEditor( -object => $list )->pack;
     $cw->add_summary($list)->pack(@fx);
-    $cw->add_description($list)->pack(@fx);
+    $cw->add_description($list)->pack(@fbe1);
     $cw->add_warning( $list, 'edit' )->pack(@fx);
     $cw->add_info_button($cw)->pack(@fx);
 
