@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListViewer;
-$Config::Model::Tk::ListViewer::VERSION = '1.357';
+$Config::Model::Tk::ListViewer::VERSION = '1.358';
 use strict;
 use warnings;
 use Carp;
@@ -60,7 +60,7 @@ sub Populate {
     $cw->add_annotation($list)->pack(@fx);
     $cw->add_warning( $list, 'view' )->pack(@fx);
     $cw->add_summary($list)->pack(@fx);
-    $cw->add_description($list)->pack(@fx);
+    $cw->add_description($list)->pack(@fbe1);
 
     $cw->add_info_button()->pack( -side => 'left', @fxe1 );
     $cw->add_editor_button($path)->pack( -side => 'right', @fxe1 );
