@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::NodeEditor;
-$Config::Model::Tk::NodeEditor::VERSION = '1.357';
+$Config::Model::Tk::NodeEditor::VERSION = '1.358';
 use strict;
 use warnings;
 use Carp;
@@ -69,7 +69,7 @@ sub Populate {
 
     if ( $node->parent ) {
         $cw->add_summary($node)->pack(@fx);
-        $cw->add_description($node)->pack(@fx);
+        $cw->add_description($node)->pack(@fbe1);
     }
     else {
         $cw->add_help( class => $node->get_help )->pack(@fx);
