@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.357';
+$Config::Model::TkUI::VERSION = '1.358';
 use 5.10.1;
 use strict;
 use warnings;
@@ -190,6 +190,14 @@ sub Populate {
     )->pack( -side => 'right' );
     $loc_frame->Label( -text => 'show only custom values' )->pack( -side => 'right' );
 
+    # create 'hide empty values'
+    $cw->{hide_empty_values} = 0;
+    $loc_frame->Checkbutton(
+        -variable => \$cw->{hide_empty_values},
+        -command  => sub { $cw->reload },
+    )->pack( -side => 'right' );
+    $loc_frame->Label( -text => 'hide empty values' )->pack( -side => 'right' );
+
     # add bottom frame
     my $bottom_frame = $cw->Frame->pack(qw/-pady 0 -fill both -expand 1/);
 
@@ -200,6 +208,7 @@ sub Populate {
         -columns   => 4,
         -header    => 1,
         -opencmd   => sub { $cw->open_item(@_); },
+        -closecmd  => sub { $cw->close_item(@_); },
     )->pack(qw/-fill both -expand 1 -side left/);
     $cw->{tktree} = $tree;
 
@@ -386,7 +395,7 @@ sub add_help_menu {
 # Note: this callback is called by Tk::Tree *before* changing the
 # indicator. And the indicator is used by Tk::Tree to store the
 # open/close/none mode. So we can't rely on getmode for path that are
-# opening. HEnce the parameter passed to the sub stored with each
+# opening. Hence the parameter passed to the sub stored with each
 # Tk::Tree item
 sub open_item {
     my ( $cw, $path ) = @_;
@@ -398,11 +407,26 @@ sub open_item {
     # the parameter indicates that we are opening this path
     $data->[0]->(1);
 
+    $cw->show_single_list_value ($tktree, $data->[1], $path, 0);
+
     my @children = $tktree->infoChildren($path);
     $logger->trace("open_item show @children");
     map { $tktree->show( -entry => $_ ); } @children;
 }
 
+sub close_item {
+    my ( $cw, $path ) = @_;
+    my $tktree = $cw->{tktree};
+    $logger->trace("close_item on $path");
+    my $data = $tktree->infoData($path);
+
+    $cw->show_single_list_value ($tktree, $data->[1], $path, 1);
+
+    my @children = $tktree->infoChildren($path);
+    $logger->trace("close_item hide @children");
+    map { $tktree->hide( -entry => $_ ); } @children;
+}
+
 sub save_in_dir {
     my $cw = shift;
     require Tk::DirSelect;
@@ -671,15 +695,26 @@ sub disp_obj_elt {
     my $tkt  = $cw->{tktree};
     my $mode = $tkt->getmode($path);
 
-    if ($cw->{show_only_custom}) {
+    if ($cw->{show_only_custom} or $cw->{hide_empty_values}) {
         my @new_element_list;
         foreach my $elt ( @element_list ) {
-            my $elt_type = $node->element_type($elt);
-            push @new_element_list, $elt if $node->fetch_element($elt)->has_data;
+            my $obj = $node->fetch_element($elt);
+            if ($cw->{show_only_custom}) {
+                push @new_element_list, $elt if $node->fetch_element($elt)->has_data;
+            }
+            elsif ($cw->{hide_empty_values}) {
+                my $elt_type = $obj->get_type;
+                my $show
+                    = $elt_type eq 'hash'       ? $obj->has_data
+                    : $elt_type eq 'list'       ? $obj->has_data
+                    : $elt_type eq 'leaf'       ? length($obj->fetch(qw/mode user check no/) // '')
+                    : $elt_type eq 'check_list' ? $obj->fetch(mode => 'user')
+                    :                             1 ;
+                push @new_element_list, $elt if $show;
+            }
         }
         @element_list = @new_element_list;
     }
-
     $logger->trace( "disp_obj_elt path $path mode $mode opening $opening " . "(@element_list)" );
 
     $cw->prune( $path, @element_list );
@@ -717,14 +752,35 @@ sub disp_obj_elt {
 
         $cw->setmode( 'node', $newpath, $eltmode, $elt_loc, $fd_path, $opening, $scan_sub );
 
+        my $obj = $node->fetch_element($elt);
         if ( $elt_type eq 'hash' ) {
-            $cw->update_hash_image( $node->fetch_element($elt), $newpath );
+            $cw->update_hash_image( $obj, $newpath );
         }
 
+        if ($elt_type eq 'hash' or $elt_type eq 'list') {
+            my $size = $obj->fetch_size;
+            $tkt->entryconfigure($newpath, -text => "$elt [$size]");
+        }
+
+        $cw->show_single_list_value ($tkt, $obj, $newpath,  $tkt->getmode($newpath) eq 'open' ? 1 : 0);
+
         $prevpath = $newpath;
     }
 }
 
+# show a list like a leaf value when the list contains *one* item
+sub show_single_list_value {
+    my ($cw, $tkt, $obj, $path, $show) = @_;
+    my $elt_type = $obj->get_type;
+    $logger->trace("show_single_list_value called on ", $obj->location);
+    if ($elt_type eq 'list' and $obj->get_cargo_type eq 'leaf' and $obj->fetch_size == 1 and $show) {
+        disp_leaf(undef,[ $path, $cw ], $obj->parent, $obj->element_name, 0, $obj->fetch_with_id(0));
+    }
+    else {
+        map {$tkt->itemDelete( $path, $_ ) if $tkt->itemExists($path, $_);} qw/1 2 3/;
+    }
+}
+
 sub disp_hash {
     my ( $scanner, $data_ref, $node, $element_name, @idx ) = @_;
     my ( $path, $cw, $opening, $fd_path ) = @$data_ref;
